@@ -1,5 +1,8 @@
-"""Create standalone executables from Python scripts, with the same performance
-and is cross-platform.
+"""cx_Freeze.
+
+Creates standalone executables from Python scripts with the same performance
+as the original script. It is cross-platform and should work on any platform
+that Python runs on.
 """
 
 from __future__ import annotations
@@ -12,8 +15,9 @@ from cx_Freeze.command.build_exe import build_exe
 from cx_Freeze.command.install import Install as install
 from cx_Freeze.command.install_exe import install_exe
 from cx_Freeze.executable import Executable, validate_executables
-from cx_Freeze.finder import Module, ModuleFinder
-from cx_Freeze.freezer import ConstantsModule, Freezer
+from cx_Freeze.finder import ModuleFinder
+from cx_Freeze.freezer import Freezer
+from cx_Freeze.module import ConstantsModule, Module
 
 __all__ = [
     "ConstantsModule",
@@ -45,7 +49,7 @@ else:
     __all__ += ["bdist_appimage", "bdist_deb", "bdist_rpm"]
 
 
-__version__ = "8.3.0"
+__version__ = "8.5.0"
 
 
 def setup(**attrs) -> setuptools.Distribution:  # noqa: D103
