@@ -6,7 +6,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-from cx_Freeze.common import code_object_replace_function
+from cx_Freeze._bytecode import code_object_replace_function
 from cx_Freeze.module import Module, ModuleHook
 
 if TYPE_CHECKING:
