@@ -1,6 +1,4 @@
-"""Tests for hooks:
-numpy, matplotlib, pandas, raterio, scipy, shapely, and vtk.
-"""
+"""Tests for hooks: scipy, skimage and sklearn."""
 
 from __future__ import annotations
 
@@ -12,13 +10,14 @@ from cx_Freeze._compat import (
     ABI_THREAD,
     IS_ARM_64,
     IS_CONDA,
+    IS_LINUX,
     IS_MACOS,
     IS_WINDOWS,
 )
 
-TIMEOUT = 10
-TIMEOUT_SLOW = 60 if IS_CONDA else 20
-TIMEOUT_VERY_SLOW = 90 if IS_CONDA else 30
+TIMEOUT = 15
+TIMEOUT_SLOW = 60 if IS_CONDA else 30
+TIMEOUT_VERY_SLOW = 120 if IS_CONDA else 60
 
 zip_packages = pytest.mark.parametrize(
     "zip_packages", [False, True], ids=["", "zip_packages"]
@@ -40,11 +39,9 @@ pyproject.toml
     name = "test_scipy"
     version = "0.1.2.3"
     dependencies = [
-        "numpy<1.26;python_version <= '3.10'",
-        "numpy<2;python_version == '3.11'",
-        "numpy>=2;python_version >= '3.12'",
-        "scipy<1.9.2;python_version == '3.9'",
-        "scipy<1.16;python_version == '3.10'",
+        "numpy<2;python_version < '3.11'",
+        "numpy>=2;python_version >= '3.11'",
+        "scipy<1.16;python_version < '3.11'",
         "scipy>=1.16;python_version >= '3.11'",
     ]
 
@@ -59,12 +56,6 @@ pyproject.toml
 """
 
 
-@pytest.mark.xfail(
-    IS_WINDOWS and IS_ARM_64,
-    raises=ModuleNotFoundError,
-    reason="scipy does not support Windows arm64",
-    strict=True,
-)
 @pytest.mark.venv
 @zip_packages
 def test_scipy(tmp_package, zip_packages: bool) -> None:
@@ -117,7 +108,7 @@ pyproject.toml
     name = "test_skimage"
     version = "0.1.2.3"
     dependencies = [
-        "numpy<1.26;python_version <= '3.10'",
+        "numpy<2;python_version < '3.11'",
         "scikit-image",
     ]
 
@@ -149,6 +140,21 @@ pyproject.toml
     reason="scikit-image does not support Python 3.13t on Windows",
     strict=True,
 )
+@pytest.mark.xfail(
+    sys.version_info[:2] >= (3, 13)
+    and ABI_THREAD == "t"
+    and IS_LINUX
+    and IS_ARM_64,
+    raises=ModuleNotFoundError,
+    reason="scikit-image does not support Python 3.13t on Linux arm64",
+    strict=True,
+)
+@pytest.mark.xfail(
+    sys.version_info[:2] >= (3, 14),
+    raises=ModuleNotFoundError,
+    reason="scikit-image does not support Python 3.14+",
+    strict=True,
+)
 @pytest.mark.venv
 @zip_packages
 def test_skimage(tmp_package, zip_packages: bool) -> None:
@@ -180,10 +186,9 @@ pyproject.toml
     name = "test_sklearn"
     version = "0.1.2.3"
     dependencies = [
-        "numpy<1.26;python_version <= '3.10'",
-        "scikit-learn<1.3;python_version <= '3.10'",
-        "scikit-learn<1.5;python_version == '3.11'",
-        "scikit-learn>=1.7;python_version >= '3.12'",
+        "numpy<2;python_version < '3.11'",
+        "scikit-learn<1.7;python_version < '3.11'",
+        "scikit-learn>=1.7;python_version >= '3.11'",
     ]
 
     [tool.cxfreeze]
@@ -202,6 +207,12 @@ pyproject.toml
     reason="scikit-learn does not support Windows arm64",
     strict=True,
 )
+@pytest.mark.xfail(
+    sys.version_info[:2] >= (3, 14) and ABI_THREAD == "t",
+    raises=ModuleNotFoundError,
+    reason="scikit-image does not support Python 3.14t",
+    strict=True,
+)
 @pytest.mark.venv
 @zip_packages
 def test_sklearn(tmp_package, zip_packages: bool) -> None:
