@@ -11,11 +11,14 @@ from typing import TYPE_CHECKING
 import pytest
 
 from cx_Freeze._compat import (
+    ABI_THREAD,
     IS_ARM_64,
     IS_CONDA,
     IS_LINUX,
     IS_MINGW,
     IS_WINDOWS,
+    IS_X86_32,
+    IS_X86_64,
 )
 from cx_Freeze.dep_parser import ELFParser
 from cx_Freeze.exception import PlatformError
@@ -30,12 +33,14 @@ test.py
 
 if IS_WINDOWS:
     PACKAGE_VERSION = [("imagehlp", "bind")]
-    if IS_ARM_64:
-        PACKAGE_VERSION += [("lief", "0.16.6")]
-    elif IS_CONDA:
-        PACKAGE_VERSION += [("py-lief", "0.16.4")]
-    else:
-        PACKAGE_VERSION += [("lief", "0.15.1"), ("lief", "0.16.6")]
+    if IS_CONDA:
+        PACKAGE_VERSION += [("py-lief", "0.16.6")]
+    elif IS_ARM_64 and sys.version_info[:2] <= (3, 13) and ABI_THREAD == "":
+        PACKAGE_VERSION += [("lief", "0.16.6"), ("lief", "0.17.0")]
+    elif (IS_X86_32 or IS_X86_64) and ABI_THREAD == "":
+        if sys.version_info[:2] <= (3, 13):
+            PACKAGE_VERSION += [("lief", "0.15.1"), ("lief", "0.16.6")]
+        PACKAGE_VERSION += [("lief", "0.17.0")]
 elif IS_MINGW:
     PACKAGE_VERSION = [("imagehlp", "bind")]
 elif IS_LINUX:
